@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,8 @@
 class LdapTest;
 class KConfig;
 
-namespace KLDAP {
+namespace KLDAP
+{
 class LdapClientSearchConfig;
 }
 
@@ -46,9 +47,11 @@ public Q_SLOTS:
 protected:
     virtual KConfig *config() const;
 
-    KLDAP::LdapClientSearchConfig *m_clientSearchConfig = nullptr;
+    KLDAP::LdapClientSearchConfig *const m_clientSearchConfig;
+
 private:
     friend class LdapTest;
+    void slotRestoreDone();
     QString securityString();
 
     QString m_user;
@@ -59,14 +62,14 @@ private:
     QString m_mech;
     QString m_realm;
     QString m_baseDn;
-    int m_port;
-    KLDAP::LdapServer::Security m_security;
-    int m_version;
-    int m_pageSize;
-    int m_timeLimit;
-    int m_sizeLimit;
-    int m_entry;
-    bool m_editMode;
+    int m_port = 389;
+    KLDAP::LdapServer::Security m_security = KLDAP::LdapServer::None;
+    int m_version = 3;
+    int m_pageSize = 0;
+    int m_timeLimit = 0;
+    int m_sizeLimit = 0;
+    int m_entry = -1;
+    bool m_editMode = false;
 };
 
 #endif
