@@ -5,20 +5,20 @@
 */
 
 #include "setupmanager.h"
+#include "configfile.h"
+#include "identity.h"
+#include "ldap.h"
 #include "resource.h"
+#include "setupautoconfigkolabfreebusy.h"
+#include "setupautoconfigkolabldap.h"
+#include "setupautoconfigkolabmail.h"
+#include "setupispdb.h"
 #include "setuppage.h"
 #include "transport.h"
-#include "configfile.h"
-#include "ldap.h"
-#include "identity.h"
-#include "setupispdb.h"
-#include "setupautoconfigkolabmail.h"
-#include "setupautoconfigkolabldap.h"
-#include "setupautoconfigkolabfreebusy.h"
 
+#include <KAssistantDialog>
 #include <KEMailSettings>
 #include <kwallet.h>
-#include <KAssistantDialog>
 
 #include <QLocale>
 
@@ -103,8 +103,7 @@ void SetupManager::execute()
 {
     if (m_keyPublishingMethod != Key::NoPublishing) {
         auto key = qobject_cast<Key *>(createKey());
-        auto it = std::find_if(m_setupObjects.cbegin(), m_setupObjects.cend(),
-                               [](SetupObject *obj) -> bool {
+        auto it = std::find_if(m_setupObjects.cbegin(), m_setupObjects.cend(), [](SetupObject *obj) -> bool {
             return qobject_cast<Transport *>(obj);
         });
         if (it != m_setupObjects.cend()) {
@@ -177,8 +176,10 @@ void SetupManager::rollback()
 {
     m_page->setStatus(i18n("Failed to set up account, rolling back..."));
     const int setupObjectCount = m_objectToSetup.size() + m_setupObjects.size();
-    int remainingObjectCount = m_setupObjects.size();
-    foreach (SetupObject *obj, m_setupObjects) {
+    const int remainingObjectCount = m_setupObjects.size();
+    const auto setupObjectsList = m_setupObjects;
+    for (int i = 0; i < setupObjectsList.count(); ++i) {
+        auto obj = m_setupObjects.at(i);
         m_page->setProgress((remainingObjectCount * 100) / setupObjectCount);
         if (obj) {
             obj->destroy();
@@ -207,7 +208,7 @@ void SetupManager::setName(const QString &name)
     m_name = name;
 }
 
-QString SetupManager::name()
+QString SetupManager::name() const
 {
     return m_name;
 }
@@ -217,7 +218,7 @@ void SetupManager::setEmail(const QString &email)
     m_email = email;
 }
 
-QString SetupManager::email()
+QString SetupManager::email() const
 {
     return m_email;
 }
@@ -227,12 +228,12 @@ void SetupManager::setPassword(const QString &password)
     m_password = password;
 }
 
-QString SetupManager::password()
+QString SetupManager::password() const
 {
     return m_password;
 }
 
-QString SetupManager::country()
+QString SetupManager::country() const
 {
     return QLocale::countryToString(QLocale().country());
 }
@@ -259,6 +260,7 @@ void SetupManager::setKeyPublishingMethod(Key::PublishingMethod method)
 
 void SetupManager::openWallet()
 {
+    // Remove it we need to update qt5keychain
     using namespace KWallet;
     if (Wallet::isOpen(Wallet::NetworkWallet())) {
         return;
@@ -271,7 +273,7 @@ void SetupManager::openWallet()
     loop.exec();
 }
 
-bool SetupManager::personalDataAvailable()
+bool SetupManager::personalDataAvailable() const
 {
     return m_personalDataAvailable;
 }
